@@ -1,7 +1,16 @@
 import time
 from .game import Game, SeekerException, HiderException
-from .hider import Hider
-from .seeker import Seeker
+
+try:
+    from .hider import Hider
+except Exception as e:
+    hider_errors = 25
+
+try:
+    from .seeker import Seeker
+except Exception as e:
+    seeker_errors = 25
+
 import random
 
 class Match:
@@ -46,15 +55,21 @@ class Match:
                 start = time.time()
                 game = Game(hider, seeker, seed, render=False)
                 winner, timesteps = game.game_loop()
-                self._seeker_points += game.max_turns - timesteps
-                self._hider_points += timesteps
+                seeker_score = game.max_turns - timesteps
+                hider_score = timesteps
+                self._seeker_points += seeker_score
+                self._hider_points += hider_score
+                self._seeker_info.append(f"Game {i}, Seed {self._valid_seeds[i]}, Seeker Score {seeker_score}, Hider Score {hider_score}")
+                self._hider_info.append(f"Game {i}, Seed {self._valid_seeds[i]}, Seeker Score {seeker_score}, Hider Score {hider_score}")
                 finish_time = time.time()
             except SeekerException as e:
                 self._seeker_errors += 1
                 self._seeker_info.append(f"Game {i}, Seed {self._valid_seeds[i]}, {e}")
+                self._hider_info.append(f"Game {i}, Seed {self._valid_seeds[i]}, Seeker got error. Hider not penalized")
             except HiderException as e:
                 self._hider_errors += 1
                 self._hider_info.append(f"Game {i}, Seed {self._valid_seeds[i]}, {e}")
+                self._seeker_info.append(f"Game {i}, Seed {self._valid_seeds[i]}, Hider got error. Seeker not penalized")
 
             print("Total time (sec):", finish_time - start)
             print(f"winner: {winner}")
